@@ -49,7 +49,7 @@ class Command(BaseCommand):
                 if options["follow"]:
                     try:
                         link["link"] = self.follow_redirects(link["link"])
-                    except Exception, e:
+                    except Exception as e:
                         print "%s - skipping %s" % (e, link["link"])
                         continue
                 link["user_id"] = user_id
@@ -66,7 +66,6 @@ class Command(BaseCommand):
             link["link"] = entry.summary.split('href="')[2].split('"')[0]
         except IndexError:
             link["link"] = entry.link
-
         try:
             publish_date = entry.published_parsed
         except AttributeError:
@@ -85,8 +84,8 @@ class Command(BaseCommand):
     def follow_old(self):
         for link in Link.objects.all():
             try:
-                link = self.follow_redirects(link.link)
-            except Exception, e:
+                new_url = self.follow_redirects(link.link)
+            except Exception as e:
                 print "%s - skipping %s" % (e, link.link)
             else:
-                Link.objects.filter(id=link.id).update(link=link)
+                Link.objects.filter(id=link.id).update(link=new_url)
