@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 from collections import defaultdict
 from django import template
+from django.template.defaultfilters import timesince
 
 from drum.links.utils import order_by_score
 from drum.links.views import CommentList
@@ -22,3 +23,8 @@ def order_comments_by_score_for(context, link):
         comments[comment.replied_to_id].append(comment)
     context["all_comments"] = comments
     return ""
+
+
+@register.filter
+def short_timesince(date):
+    return timesince(date).split(",")[0]
